CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
50 lines
1.7 KiB
LLVM
50 lines
1.7 KiB
LLVM
; RUN: llc < %s -mtriple=nvptx64-nvidia-cuda | FileCheck %s
|
|
; RUN: %if ptxas %{ llc < %s -mtriple=nvptx64-nvidia-cuda | %ptxas-verify %}
|
|
|
|
; // Bitcode in this test case is reduced version of compiled code below:
|
|
;extern "C" {
|
|
;#line 1 "/source/dir/foo.h"
|
|
;__device__ void foo() {}
|
|
;#line 2 "/source/dir/bar.cu"
|
|
;__device__ void bar() {}
|
|
;}
|
|
|
|
; CHECK: .target sm_{{[0-9]+$}}
|
|
|
|
; CHECK: .visible .func foo()
|
|
; CHECK: .loc [[FOO:[0-9]+]] 1 31
|
|
; CHECK: ret;
|
|
; CHECK: .visible .func bar()
|
|
; CHECK: .loc [[BAR:[0-9]+]] 2 31
|
|
; CHECK: ret;
|
|
|
|
define void @foo() !dbg !4 {
|
|
bb:
|
|
ret void, !dbg !10
|
|
}
|
|
|
|
define void @bar() !dbg !7 {
|
|
bb:
|
|
ret void, !dbg !11
|
|
}
|
|
|
|
; CHECK-DAG: .file [[FOO]] "/source/dir{{/|\\\\}}foo.h"
|
|
; CHECK-DAG: .file [[BAR]] "/source/dir{{/|\\\\}}bar.cu"
|
|
|
|
; CHECK-NOT: .section .debug{{.*}}
|
|
|
|
!llvm.dbg.cu = !{!0}
|
|
!llvm.module.flags = !{!8, !9}
|
|
|
|
!0 = distinct !DICompileUnit(language: DW_LANG_C_plus_plus, file: !1, producer: "", isOptimized: false, runtimeVersion: 0, emissionKind: DebugDirectivesOnly, enums: !2)
|
|
!1 = !DIFile(filename: "bar.cu", directory: "/source/dir")
|
|
!2 = !{}
|
|
!4 = distinct !DISubprogram(name: "foo", scope: !5, file: !5, line: 1, type: !6, isLocal: false, isDefinition: true, scopeLine: 1, flags: DIFlagPrototyped, isOptimized: false, unit: !0, retainedNodes: !2)
|
|
!5 = !DIFile(filename: "foo.h", directory: "/source/dir")
|
|
!6 = !DISubroutineType(types: !2)
|
|
!7 = distinct !DISubprogram(name: "bar", scope: !1, file: !1, line: 2, type: !6, isLocal: false, isDefinition: true, scopeLine: 2, flags: DIFlagPrototyped, isOptimized: false, unit: !0, retainedNodes: !2)
|
|
!8 = !{i32 2, !"Dwarf Version", i32 2}
|
|
!9 = !{i32 2, !"Debug Info Version", i32 3}
|
|
!10 = !DILocation(line: 1, column: 31, scope: !4)
|
|
!11 = !DILocation(line: 2, column: 31, scope: !7)
|